#!/usr/bin/env node
/* eslint-disable no-process-exit */
/* eslint-disable @typescript-eslint/no-var-requires */
const cli = require('../build/cli.js')
const { frameworkLogger } = require('../build/logger.js')
const nodemon = require('nodemon')

const args = process.argv.slice(2)
const watchFlag = ['--watch', '-w']
const defaultIgnoreFiles = ['logs/*.*']

if (watchFlag.some(flag => args.includes(flag))) {
  const cmd = args.filter(arg => !watchFlag.includes(arg)).join(' ')
  nodemon({
    script: cmd,  // pass original cmd to nodemon
    exec: process.argv[1],
    watchOptions: {
      usePolling: true, // should be enabled
      ignorePermissionErrors: true,
      ignored: defaultIgnoreFiles.join(','), // ignored must not be empty string
      persistent: true,
      interval: 500
    }
  }).on('start', () => {
    frameworkLogger.info('Initializing server in watch mode. Changes in source files will trigger a restart.')
  }).on('quit', (e) => {
    frameworkLogger.info(`Nodemon quit with code ${e}.`)
    process.exit(0)
  }).on('restart', (files) => {
    frameworkLogger.info(`Server restarted due to changed files: ${files?.join(', ')}`)
  }).on('log', (e) => {
    frameworkLogger.info(`[nodemon ${e.type}] ${e.message}`)
  }).on('crash', (e) => {
    frameworkLogger.error(`Server crashed due to ${e}.`)
    process.exit(1)
  }).on('exit', (e) => {
    frameworkLogger.info(`Server exited with code ${e}.`)
  })
} else {
  cli.runCLI(args)
}
