import { MultiFnConfig, SignatureType } from './types';
export declare class ConfigurableOption<T> {
    readonly inputOption: string;
    readonly alias: string;
    private envVar;
    private defaultValue;
    private transform?;
    constructor(inputOption: string, alias: string, envVar: string, defaultValue: T, transform?: ((value: T | string) => T | Error) | undefined);
    parse(dict: Record<string, any>, envVars: NodeJS.ProcessEnv): T;
}
export interface FunctionDefinition {
    functionName: string;
    directory: string;
    sourceLocation: string;
    target: string;
}
export interface FrameworkOptions {
    /**
     * The port to listen on. Default: 3000.
     */
    port: number;
    /**
     * The target function name to load. Default: 'main'.
     */
    target: string;
    /**
     * The relative path to the source file. Default: 'index.js'.
     */
    sourceLocation: string;
    /**
     * The signature type of the function. Default: 'event'.
     * Supported values: 'event'.
     */
    signatureType: SignatureType;
    /**
     * The maximum number of instantaneously incoming requests. 0 means no limit. Default: 0.
     * Requests exceeding this limit will receive a 429 response indicating the server is busy.
     */
    concurrencyLimit: number;
    /**
     * Node.js server timeout in milliseconds. Default: 0.
     */
    timeoutMS: number;
    /**
     * The keep-alive timeout in milliseconds. Default: 25000.
     */
    keepAliveTimeoutMS: number;
    /**
     * Whether server should wait for ongoing requests to complete before shutting down.
     * Default true when 'NODE_ENV=production' otherwise false.
     */
    gracefulShutdown: boolean;
    /**
     * If true, only validate the function and exit. Default: false.
     */
    dryRun: boolean;
    /**
     * If true, process.exit calls will have no effect. Default: false.
     */
    noExit: boolean;
    /**
     * If true, intercept console、process.stdout、process.stderr output. Default: false.
     */
    interceptOutput: boolean;
    /**
     * If true, stack traces of error will be returned in the response.
     * Default: if NODE_ENV is 'production', false; otherwise, true.
     */
    captureStack: boolean;
    /**
     * If true, request and response headers and body will be logged
     * into accesslog with body size limited to 1KB. Default: false.
     */
    logHeaderBody: boolean;
    /**
     * If true, log event and context function received in the access log. Default: false.
     */
    logEventContext?: boolean;
    /**
     * If true, print help text and exit. Default: false.
     */
    printHelp?: boolean;
    /**
     * The directory to store log files. Default: 'logs'.
     */
    logDirname?: string;
    /**
     * The maximum size of a log file in bytes. Default: 128MB.
     */
    maxLogFileSize?: number;
    /**
     * The maximum number of log files to keep. Default: 4.
     */
    maxLogFiles?: number;
    /**
     * The key of headers to parse `context.extendedContext`. `''` means that the feature is turned off, Default: ''.
     */
    extendedContextKey: string;
    /**
     * The multi-functions definition config file. Default: 'cloudbase-functions.json'.
     */
    functionsConfigFile?: string;
    /**
     * The multi-functions config.
     */
    multiFunctionsConfig?: MultiFnConfig;
}
export declare const helpText: string;
export declare const parseOptions: (cliArgs?: string[], envVars?: NodeJS.ProcessEnv) => FrameworkOptions;
//# sourceMappingURL=options.d.ts.map